clear
set more off
set matsize 1000
capture log close

log using reg-results, text replace

use "data group success.dta", clear

***** Cross-sectional data & var construction
gen ly = ln(gdppercapita)
gen lpop = ln(pop)
gen lelv = ln(elevation) 
gen nontercst = nonterr_casualties/pop
replace nontercst=nontercst*1000000  // 78% zeros
bysort gid: egen maxsize=max(peak_size)
gen lnpeaksize=ln(maxsize)
foreach var of varlist ly lpop polity {
	gen `var'1=`var'
	}
gen pt=(pt_or_v=="pt")	// 84 groups
gen vic=(pt_or_v=="v")	// 19 groups
replace pt=. if endstr==0
replace vic=. if endstr==0

keep gid y_start y_end endstr pt vic lnpeaksize num_base lelv tropics landlock ///
	pch tch ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA shr_trans ///
	nontercst competitor diversity ly lpop polity ly1 lpop1 polity1
collapse (max) y_start y_end endstr pt vic lnpeaksize num_base lelv tropics ///
	landlock pch tch ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA ///
	(mean) shr_trans nontercst competitor diversity ///
	(first) ly lpop polity ///
	(firstnm) ly1 lpop1 polity1, by(gid)
gen duration=y_end-y_start
replace duration=2016-y_start if duration==. 
gen lnontercst=ln(nontercst+1)
gen lcomp=ln(competitor+1)
gen end=(endstr!=0)
gen success=(endstr==3)
replace success=. if endstr==0

**********************************************************************
****** Table 1.  Terrorist groups' characteristics and fate, 1970–2016
**********************************************************************
gen ideology = ""
replace ideology = "Left wing" if left == 1
replace ideology = "Nationalist" if nat == 1
replace ideology = "Religious" if rel == 1
replace ideology = "Right wing" if right == 1
label define endstr1 0 "Active" 1 "Military/Policing" 2 "Splintering" ///
	3 "Politics/Victory" 4 "Merging" 5 "Not Active within 5 years"
label values endstr endstr1
label var endstr "Group's fate"
qui probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1, rob
tab endstr if e(sample) // Upper panel: Columns 2, 3
table endstr if e(sample), c(mean competitor mean lnpeaksize) // Upper panel: Columns 4, 5
tab endstr ideology if e(sample) // Lower panel


************************************************************
****** Table 2 Descriptive statistics (Cross-Sectional Data)
************************************************************
qui probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1, rob
outreg2 using Table2.xls if e(sample)==1, replace sum(log) keep(success end ///
	lnpeaksize rel left nat right sq ercsr pch tch competitor shr_trans ///
	diversity lnontercst num_base duration lelv tropics landlock MENA EAP ECA ///
	LAC NA SAS SSA lpop1 polity1 ly1) sortvar(end success lnpeaksize rel left ///
	nat right competitor shr_trans diversity lnontercst num_base duration sq ///
	ercsr pch tch ly1 lpop1 polity1 lelv tropics landlock MENA EAP ECA LAC NA ///
	SAS SSA) ///
	title("Table 2.  Descriptive statistics")	
qui probit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1, rob
outreg2 using Table2.xls if e(sample)==1, sum(log) keep(success end lnpeaksize ///
	rel left nat right sq ercsr pch tch competitor shr_trans diversity ///
	lnontercst num_base duration lelv tropics landlock MENA EAP ECA LAC NA SAS ///
	SSA lpop1 polity1 ly1) sortvar(end success lnpeaksize rel left nat right ///
	competitor shr_trans diversity lnontercst num_base duration sq ercsr pch ///
	tch ly1 lpop1 polity1 lelv tropics landlock MENA EAP ECA LAC NA SAS SSA)


**********************************************************************
****** Table 3	Cross-sectional analysis: Probit with sample selection
**********************************************************************
heckprobit success lnpeaksize i.left i.nat i.right competitor shr_trans ///
	diversity, sel(end=lnpeaksize i.left i.nat i.right competitor shr_trans ///
	diversity lnontercst num_base duration) vce(rob)
    outreg2 using Table3.xls, dec(3) label replace ctitle(Model 1) ///
	title("Table 3.  Probit regressions with sample selection")
heckprobit success lnpeaksize i.left i.nat i.right competitor shr_trans ///
	diversity i.ercsr i.pch i.tch lpop1 polity1, sel(end=lnpeaksize i.left ///
	i.nat i.right competitor shr_trans diversity lnontercst num_base duration ///
	i.ercsr i.pch i.tch ly1 lpop1 polity1 lelv tropics landlock EAP ECA LAC ///
	NA SAS SSA) vce(rob)
	outreg2 using Table3.xls, dec(3) label append ctitle(Model 2)


****************************************************************************
****** Table 4 Cross-sectional analysis: Probit & (average) marginal effects
****************************************************************************
probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base duration i.ercsr i.pch i.tch ly1 lpop1 polity1 ///
	lelv tropics landlock EAP ECA LAC NA SAS SSA, rob
    outreg2 using Table4.xls, dec(3) label replace ctitle(End: Coeff.) ///
	title("Table 4.  Probit regressions")
est store end
margins, dydx(*) post // Average ME
outreg2 using Table4.xls, dec(3) label append ctitle(End: Average ME)
testparm 1.left 1.nat, equal
testparm 1.left 1.right, equal
testparm 1.right 1.nat, equal
probit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1, rob
    outreg2 using Table4.xls, dec(3) label append ctitle(Success: Coeff)
est store success
margins, dydx(*) post // Average ME
outreg2 using Table4.xls, dec(3) label append ctitle(Success: Average ME)
testparm 1.left 1.nat, equal
testparm 1.left 1.right, equal
testparm 1.right 1.nat, equal


***************************************************************************
****** Table available upon request: separate vars for democracy/autoc/anoc 
***************************************************************************		
gen autocrac=(polity1<-5.5) if !missing(polity1)
gen anocrac=(polity1>=-5.5) & (polity1<5.5) if !missing(polity1)
gen democrac=(polity1>=5.5) if !missing(polity1)

heckprobit success lnpeaksize i.left i.nat i.right competitor shr_trans ///
	diversity i.ercsr i.pch i.tch lpop1 democrac autocrac, sel(end=lnpeaksize ///
	i.left i.nat i.right competitor shr_trans diversity lnontercst num_base ///
	duration i.ercsr i.pch i.tch ly1 lpop1 democrac autocrac lelv tropics ///
	landlock EAP ECA LAC NA SAS SSA) vce(rob)
	outreg2 using TableRobust.xls, dec(3) label replace ctitle(Prob SSelection) ///
	title("Table. Replacing polity with democracy and autocracy variables")
probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base duration i.ercsr i.pch i.tch ly1 lpop1 democrac autocrac ///
	lelv tropics landlock EAP ECA LAC NA SAS SSA, rob
    outreg2 using TableRobust.xls, dec(3) label append ctitle(End)	
probit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 democrac autocrac, rob
    outreg2 using TableRobust.xls, dec(3) label append ctitle(Success)


**************************************
****** Table 5 Robustness regressions
**************************************	
// Remove mergers -- may not be failures but can't put into success either
probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base duration i.ercsr i.pch i.tch ly1 lpop1 polity1 ///
	lelv tropics landlock EAP ECA LAC NA SAS SSA if endstr!=4, rob
	outreg2 using Table5.xls, dec(3) label replace ctitle(End: Remove Merger) ///
	title("Table 5. Robustness regressions")
probit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1 if endstr!=4, rob
	outreg2 using Table5.xls, dec(3) label append ctitle(Success: Remove Merger)
// disaggregate success into politics and victory
probit pt lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1 if vic!=1, rob
	outreg2 using Table5.xls, dec(3) label append ctitle(Success: Politics)
tab pt if e(sample)==1  // 70 (pt) groups out of 84
firthlogit vic lnpeaksize i.left i.nat i.right diversity if pt!=1 // Penalized ML logit
	outreg2 using Table5.xls, dec(3) label append ctitle(FirthLogit Succ: Victory)
tab vic if e(sample)==1  // 15 (vic) groups out of 19


****************************************************
****** Table 6 Panel analysis: Random effects probit
****************************************************	
// Annual analysis
use "data group success.dta", clear
gen t = duration
gen t2 = duration ^ 2
gen ly = ln(gdppercapita)
gen lpop = ln(pop)
gen lelv = ln(elevation) 
gen nontercst = nonterr_casualties/pop
replace nontercst=nontercst*1000000  // 78% zeros
gen lnontercst=ln(nontercst+1)
gen end=(endstr!=0)
bysort gid: egen maxsize=max(peak_size)
gen lnpeaksize=ln(maxsize)
gen success=(endstr==3)
bysort gid: egen temp=max(end)
replace success=. if temp==0

xtset gid year
xtprobit end t t2 lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base ly lpop polity lelv tropics landlock EAP ECA LAC NA ///
	SAS SSA i.year, vce(rob) re
    outreg2 using Table6.xls, dec(3) label replace ctitle(Annual: End) ///
	title("Table 6. Random effects probit regressions") drop(i.year)
xtprobit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lpop polity i.year, vce(rob) re
    outreg2 using Table6.xls, dec(3) label append ctitle(Annual: Success) drop(i.year)

// 5-year grouped	
use "data group success.dta", clear
gen nontercst = nonterr_casualties/pop
replace nontercst=nontercst*1000000  // 78% zeros
recode year (1970/1974=1) (1975/1979=2) (1980/1984=3) (1985/1989=4) (1990/1994=5) ///
	(1995/1999=6) (2000/2004=7) (2005/2009=8) (2010/2016=9), gen(time)
bysort gid: egen maxsize=max(peak_size)
gen lnpeaksize=ln(maxsize)

keep gid time endstr lnpeaksize num_base elevation tropics landlock pch tch ///
	ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA shr_trans nontercst ///
	competitor diversity gdppercapita pop polity duration
sort gid time
collapse (max) endstr lnpeaksize num_base elevation tropics landlock pch tch ///
	ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA duration ///
	(mean) shr_trans nontercst competitor diversity pop gdppercapita ///
	polity, by(gid time)

gen ly = ln(gdppercapita)
gen lpop = ln(pop)
gen lelv = ln(elevation)
gen lnontercst=ln(nontercst+1)
gen end=(endstr!=0)
bysort gid: egen temp=max(end)
gen success=(endstr==3)
replace success=. if temp==0
tab success
drop temp
gen t = duration
gen t2 = duration ^ 2

xtset gid time
xtprobit end t t2 lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base ly lpop polity lelv tropics landlock ///
	EAP ECA LAC NA SAS SSA i.time, vce(rob) re  
    outreg2 using Table6.xls, dec(3) label append ctitle(Grouped: End) drop(i.time)
xtprobit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lpop polity i.time, vce(rob) re
    outreg2 using Table6.xls, dec(3) label append ctitle(Grouped: Success) ///
	drop(i.time)

log close
